@@ -8,8 +8,8 @@ MANAGERS = ADMINS
 
 DATABASES = {
     'default': {
-        'ENGINE': 'django.db.backends.sqlite3', # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
-        'NAME': './sqlite3.db',                      # Or path to database file if using sqlite3.
+        'ENGINE': 'django.db.backends.sqlite3',
+        'NAME': './sqlite3.db',
     }
 }
 
@@ -49,4 +49,4 @@ CACHES = {
     }
 }
 
-SEO_JS_PRERENDER_TOKEN = "123456789"
\ No newline at end of file
+SEO_JS_PRERENDER_TOKEN = "123456789"
